summaryrefslogtreecommitdiffstats
path: root/kbabel/catalogmanager/libsvn/svnhandler.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kbabel/catalogmanager/libsvn/svnhandler.cpp')
-rw-r--r--kbabel/catalogmanager/libsvn/svnhandler.cpp58
1 files changed, 29 insertions, 29 deletions
diff --git a/kbabel/catalogmanager/libsvn/svnhandler.cpp b/kbabel/catalogmanager/libsvn/svnhandler.cpp
index 1ac98f66..c648c2bb 100644
--- a/kbabel/catalogmanager/libsvn/svnhandler.cpp
+++ b/kbabel/catalogmanager/libsvn/svnhandler.cpp
@@ -20,11 +20,11 @@
In addition, as a special exception, the copyright holders give
permission to link the code of this program with any edition of
- the Qt library by Trolltech AS, Norway (or with modified versions
- of Qt that use the same license as Qt), and distribute linked
+ the TQt library by Trolltech AS, Norway (or with modified versions
+ of TQt that use the same license as TQt), and distribute linked
combinations including the two. You must obey the GNU General
Public License in all respects for all of the code used other than
- Qt. If you modify this file, you may extend this exception to
+ TQt. If you modify this file, you may extend this exception to
your version of the file, but you are not obligated to do so. If
you do not wish to do so, delete this exception statement from
your version.
@@ -36,7 +36,7 @@
#include <unistd.h>
#include <sys/stat.h>
#include <time.h>
// Qt include files
#include <tqdir.h>
#include <tqfile.h>
#include <tqfileinfo.h>
@@ -83,7 +83,7 @@ void SVNHandler::setPOTBaseDir( const TQString& dir )
emit signalIsPOTRepository( _isPOTRepository );
}
-TQString SVNHandler::fileStatus( const FileStatus status ) const
+TQString SVNHandler::filetqStatus( const FiletqStatus status ) const
{
switch ( status ) {
case NO_REPOSITORY:
@@ -115,7 +115,7 @@ TQString SVNHandler::fileStatus( const FileStatus status ) const
}
}
-SVNHandler::FileStatus SVNHandler::fstatus( const TQString& filename ) const
+SVNHandler::FiletqStatus SVNHandler::fstatus( const TQString& filename ) const
{
// no valid repository
if ( !_isPORepository )
@@ -145,7 +145,7 @@ SVNHandler::FileStatus SVNHandler::fstatus( const TQString& filename ) const
int errorLine, errorCol;
TQDomNodeList nodelist;
TQDomNode node;
- TQDomElement entry, wcStatus;
+ TQDomElement entry, wctqStatus;
// Parse the output.
if ( !doc.setContent( out.getOutput(), &errorMsg, &errorLine, &errorCol ) ) {
@@ -177,22 +177,22 @@ SVNHandler::FileStatus SVNHandler::fstatus( const TQString& filename ) const
if ( node.isNull() )
return ERROR_IN_WC;
- wcStatus = node.toElement();
+ wctqStatus = node.toElement();
- if ( wcStatus.attributeNode("item").value() == "normal" )
+ if ( wctqStatus.attributeNode("item").value() == "normal" )
return UP_TO_DATE;
- if ( wcStatus.attributeNode("item").value() == "modified" )
+ if ( wctqStatus.attributeNode("item").value() == "modified" )
return LOCALLY_MODIFIED;
- if ( wcStatus.attributeNode("item").value() == "conflicted" )
+ if ( wctqStatus.attributeNode("item").value() == "conflicted" )
return CONFLICT;
- if ( wcStatus.attributeNode("item").value() == "unversioned" )
+ if ( wctqStatus.attributeNode("item").value() == "unversioned" )
return NOT_IN_SVN;
// TODO Ignored entry should have separate return value probably.
- if ( wcStatus.attributeNode("item").value() == "ignored" )
+ if ( wctqStatus.attributeNode("item").value() == "ignored" )
return NOT_IN_SVN;
- if ( wcStatus.attributeNode("item").value() == "added" )
+ if ( wctqStatus.attributeNode("item").value() == "added" )
return LOCALLY_ADDED;
- if ( wcStatus.attributeNode("item").value() == "deleted" )
+ if ( wctqStatus.attributeNode("item").value() == "deleted" )
return LOCALLY_REMOVED;
// TODO What to do with "missing", "incomplete", "replaced", "merged",
// "obstructed", "external"? Can these appear at all in our case?
@@ -269,23 +269,23 @@ no_status_xml:
}
-TQString SVNHandler::svnStatus( const TQString& filename ) const
+TQString SVNHandler::svntqStatus( const TQString& filename ) const
{
return map[filename];
}
-void SVNHandler::execSVNCommand( TQWidget* parent, SVN::Command cmd, const TQString& filename, bool templates, KSharedConfig* config)
+void SVNHandler::execSVNCommand( TQWidget* tqparent, SVN::Command cmd, const TQString& filename, bool templates, KSharedConfig* config)
{
// Unlike cvs, svn works also from outside the repository(as long as the path is in a repository of course!)
// ### FIXME: wrong, svn commit cannot work if the current directory is not a SVN one
- execSVNCommand( parent, cmd, TQStringList( filename ), templates, config );
+ execSVNCommand( tqparent, cmd, TQStringList( filename ), templates, config );
}
-void SVNHandler::execSVNCommand( TQWidget* parent, SVN::Command cmd, const TQStringList& files, bool templates, KSharedConfig* config )
+void SVNHandler::execSVNCommand( TQWidget* tqparent, SVN::Command cmd, const TQStringList& files, bool templates, KSharedConfig* config )
{
if ( !_isPORepository ) {
// This message box should never be visible but who knows... ;-)
- KMessageBox::sorry( parent, i18n( "This is not a valid SVN repository. "
+ KMessageBox::sorry( tqparent, i18n( "This is not a valid SVN repository. "
"The SVN commands cannot be executed." ) );
return;
}
@@ -328,7 +328,7 @@ void SVNHandler::execSVNCommand( TQWidget* parent, SVN::Command cmd, const TQStr
command += " \'" + temp + "\'";
}
- showDialog( parent, cmd, files, command, config );
+ showDialog( tqparent, cmd, files, command, config );
}
void SVNHandler::setAutoUpdateTemplates( bool update )
@@ -336,9 +336,9 @@ void SVNHandler::setAutoUpdateTemplates( bool update )
_autoUpdateTemplates = update;
}
-void SVNHandler::showDialog( TQWidget* parent, SVN::Command cmd, const TQStringList& files, const TQString& commandLine, KSharedConfig* config )
+void SVNHandler::showDialog( TQWidget* tqparent, SVN::Command cmd, const TQStringList& files, const TQString& commandLine, KSharedConfig* config )
{
- SVNDialog * dia = new SVNDialog( cmd, parent, config );
+ SVNDialog * dia = new SVNDialog( cmd, tqparent, config );
dia->setFiles( files );
dia->setCommandLine( commandLine );
if ( cmd == SVN::Commit ) {
@@ -415,7 +415,7 @@ void SVNHandler::checkToAdd( const TQStringList& files )
}
// ### TODO: does SVN really needs this or does it do it automatically?
// check recursivlely if parent dirs have to be added as well
while ( ! isInSvn( temp ) && toBeAdded.findIndex( temp ) == -1 ) {
toBeAdded << temp;
temp = TQFileInfo( temp ).dirPath( true );
@@ -464,7 +464,7 @@ void SVNHandler::processStatusOutput( const TQString& status )
TQString entr = *it;
// translate the filename from repository to local
TQRegExp rx( basedir + ".*,v" );
- int pos = entr.find( rx );
+ int pos = entr.tqfind( rx );
TQString file = _poBaseDir + entr.mid( pos + basedir.length( ),
rx.matchedLength( ) - basedir.length( ) - 2 );
@@ -472,7 +472,7 @@ void SVNHandler::processStatusOutput( const TQString& status )
// TODO: do some markup
- map.replace( file, entr );
+ map.tqreplace( file, entr );
}
#endif
}
@@ -480,7 +480,7 @@ void SVNHandler::processStatusOutput( const TQString& status )
void SVNHandler::processDiff( TQString output )
{
output.remove( TQRegExp( "\\[ .* \\]$" ));
- output.remove( TQRegExp( "^" + i18n("[ Starting command ]" ).replace("[","\\[").replace("]","\\]")));
+ output.remove( TQRegExp( "^" + i18n("[ Starting command ]" ).tqreplace("[","\\[").tqreplace("]","\\]")));
KTempFile tmpFile;
*(tmpFile.textStream()) << output;
@@ -491,7 +491,7 @@ void SVNHandler::processDiff( TQString output )
KMessageBox::error( 0, error );
}
-bool SVNHandler::isConsideredModified( const FileStatus status ) const
+bool SVNHandler::isConsideredModified( const FiletqStatus status ) const
{
/*
* A file is modified if it is either:
@@ -541,4 +541,4 @@ void SVNOutputCollector::slotGatherStdout( KProcess*, char* data, int len )
#include "svnhandler.moc"
-// kate: space-indent on; indent-width 2; replace-tabs on;
+// kate: space-indent on; indent-width 2; tqreplace-tabs on;
@@ -36,7 +36,7 @@
#include <sys/stat.h>
#include <time.h>
-// Qt include files
+// TQt include files
#include <tqdir.h>
#include <tqfile.h>
@@ -415,7 +415,7 @@ void SVNHandler::checkToAdd( const TQStringList& files )
}
// ### TODO: does SVN really needs this or does it do it automatically?
- // check recursivlely if parent dirs have to be added as well
+ // check recursivlely if tqparent dirs have to be added as well
while ( ! isInSvn( temp ) && toBeAdded.findIndex( temp ) == -1 ) {
toBeAdded << temp;